California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance Activity Propositions & Ballot Measures
Election Cycle: 2021 through 2022 Historical 2019 through 2020 2017 through 2018 2015 through 2016 2013 through 2014 2011 through 2012 2009 through 2010 2007 through 2008 2005 through 2006 2003 through 2004 2001 through 2002 1999 through 2000
All of the campaign committees that have organized to support or oppose propositions and ballot measures on California's statewide ballot are available here. Click below on the proposition or ballot measure to learn who is involved in the campaign to win your vote on Election Day.
Prior Elections
NOVEMBER 4, 2008, GENERAL
12 Measures
PROPOSITION 001A - SAFE, RELIABLE HIGH-SPEED PASSENGER TRAIN BOND ACT.
PROPOSITION 002 - STANDARDS FOR CONFINING FARM ANIMALS. INITIATIVE STATUTE.
PROPOSITION 003 - CHILDREN'S HOSPITAL BOND ACT. GRANT PROGRAM. INITIATIVE STATUTE.
PROPOSITION 004 - WAITING PERIOD AND PARENTAL NOTIFICATION BEFORE TERMINATION OF MINOR'S PREGNANCY. INITIATIVE CONSTITUTIONAL AMENDMENT.
PROPOSITION 005 - NONVIOLENT DRUG OFFENSES. SENTENCING, PAROLE AND REHABILITATION. INITIATIVE STATUTE.
PROPOSITION 006 - POLICE AND LAW ENFORCEMENT FUNDING. CRIMINAL PENALTIES AND LAWS. INITIATIVE STATUTE.
PROPOSITION 007 - RENEWABLE ENERGY GENERATION. INITIATIVE STATUTE.
PROPOSITION 008 - ELIMINATES RIGHT OF SAME-SEX COUPLES TO MARRY. INITIATIVE CONSTITUTIONAL AMENDMENT.
PROPOSITION 009 - CRIMINAL JUSTICE SYSTEM. VICTIMS' RIGHTS. PAROLE. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROPOSITION 010 - ALTERNATIVE FUEL VEHICLES AND RENEWABLE ENERGY. BONDS. INITIATIVE STATUTE.
PROPOSITION 011 - REDISTRICTING. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROPOSITION 012 - VETERANS' BOND ACT OF 2008.
JUNE 3, 2008, RECALL
1 Measure
JUNE 3, 2008 - SPECIAL RECALL ELECTION - SENATE DISTRICT 12
JUNE 3, 2008, PRIMARY
2 Measures
PROP 98 - EMINENT DOMAIN. LIMITS ON GOVERNMENT AUTHORITY. INITIATIVE CONSTITUTIONAL AMENDMENT.
PROP 99 - EMINENT DOMAIN. LIMITS ON GOVERNMENT ACQUISITION OF OWNER-OCCUPIED RESIDENCE. INITIATIVE CONSTITUTIONAL AMENDMENT.
FEBRUARY 5, 2008, PRIMARY
7 Measures
PROP 91 - TRANSPORTATION FUNDING. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROP 92 - COMMUNITY COLLEGES. FUNDING. GOVERNANCE. FEES. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROP 93 - LIMITS ON LEGISLATORS' TERMS IN OFFICE. INITIATIVE CONSTITUTIONAL AMENDMENT.
PROP 94 - REFERENDUM ON AMENDMENT TO INDIAN GAMING COMPACT. (CHAPTER 40, STATUTES OF 2007)
PROP 95 - REFERENDUM ON AMENDMENT TO INDIAN GAMING COMPACT. (CHAPTER 38, STATUTES OF 2007)
PROP 96 - REFERENDUM ON AMENDMENT TO INDIAN GAMING COMPACT. (CHAPTER 39, STATUTES OF 2007)
PROP 97 - REFERENDUM ON AMENDMENT TO INDIAN GAMING COMPACT. (CHAPTER 41, STATUTES OF 2007)